@@ -25,8 +25,9 @@ GtkWidget *blanker_window;
 static Bool PopupIsMapped = False;
 
 static Bool ScreenBlank = False;
-static Bool SuspendDisabled = False;
 static Bool ScreensaverDisabled = False;
+static Bool SuspendDisabled = False;
+static Bool XmmsControl = True;
 
 int config_backlight, config_screensaver, config_suspend;
 int custom_backlight = 0;
@@ -105,14 +106,14 @@ volatile Bool WantReload     = False;
 
 static void reap_children (int signum);
 static void fork_exec (char *cmd);
-static void usage ();
 static void build_menu (void);
 static void catch_sigsegv (int sig);
 static void load_icons(void);
 void add_suspend_item();
 void remove_suspend_item();
-static void suspend_toggle_cb(MBMenuItem *item);
 static void screensaver_toggle_cb(MBMenuItem *item);
+static void suspend_toggle_cb(MBMenuItem *item);
+static void xmms_control_toggle_cb(MBMenuItem *item);
 void backlight_timeout_callback ( MBTrayApp *app );
 static gboolean key_event_callback( GtkWidget      *widget, 
 				    GdkEventKey    *event,
@@ -151,18 +152,6 @@ static void sn_exec(char* name, char* bin_name, char *desc);
 #define DBG(txt, args... ) /* nothing */
 #endif
 
-static void usage()
-{
-  printf("usage: mbmenu [options ....]\n"
-	  "Where options are\n"
-	  "  -display <display> Display to connect to\n"
-	  "\nAlso set MB_USE_DEB_MENUS env var to enable parsing /usr/lib/menu"
-	  "\n"
-
-	  );
-   exit(1);
-}
-
 static void catch_sigsegv(int sig)
 {
    DBG("ouch\n");
@@ -323,15 +312,6 @@ void reload_icons()
   mb_tray_app_repaint (app_data->tray_app);
 }
 
-static
-void suspend_toggle_cb(MBMenuItem *item)
-{
-  SuspendDisabled = SuspendDisabled ? False : True;
-
-  set_dpms();
-
-  reload_icons();
-}
 
 static
 void screensaver_toggle_cb(MBMenuItem *item)
@@ -344,20 +324,52 @@ void screensaver_toggle_cb(MBMenuItem *item)
 }
 
 static
-void read_backlight()
+void suspend_toggle_cb(MBMenuItem *item)
+{
+  SuspendDisabled = SuspendDisabled ? False : True;
+
+  set_dpms();
+
+  reload_icons();
+}
+
+static
+void xmms_control_toggle_cb(MBMenuItem *item)
+{
+  XmmsControl = XmmsControl ? False : True;
+
+  reload_icons();
+}
+
+
+int get_backlight()
 {
    FILE *bl;
    char line[255];
-   int buffer;
-
-   read_lnp_config();
+   int buffer = 0;
 
    if ((bl = fopen("/proc/driver/fl/corgi-bl", "r"))) {
      if (fgets(line,sizeof(line),bl) != NULL) {
        sscanf(line,"%i", &buffer);
-       fclose(bl);
+     }
+     fclose(bl);
+   }
 
-       switch (buffer) {
+   return buffer;
+}
+
+static
+void read_backlight()
+{
+   int buffer;
+
+   read_lnp_config();
+
+   buffer = get_backlight();
+
+   if (buffer >= 0) {
+     switch (buffer)
+       {
        case 287: buffer = 6; break;
        case 267: buffer = 5; break;
        case 261: buffer = 4; break;
@@ -367,17 +379,15 @@ void read_backlight()
        default : buffer = 0;
        }
 
-       if (buffer > 0) {
-	 if (buffer != config_backlight) {
-	   custom_backlight = buffer;
-	 } else {
-	   custom_backlight = 0;
-	 }
+     if (buffer > 0) {
+       if (buffer != config_backlight) {
+	 custom_backlight = buffer;
+       } else {
+	 custom_backlight = 0;
        }
-
      }
    }
-}
+ }
 
 static
 void disable_backlight()
@@ -430,8 +440,9 @@ static void
 build_menu(void)
 {
   MBMenuMenu *m = app_data->mbmenu->rootmenu;
-  MBMenuActivateCB suspend_callback = suspend_toggle_cb;
   MBMenuActivateCB screensaver_callback = screensaver_toggle_cb;
+  MBMenuActivateCB suspend_callback = suspend_toggle_cb;
+  MBMenuActivateCB xmms_callback = xmms_control_toggle_cb;
   MBMenuActivateCB blanker_callback = blanker_cb;
   char *png_path = "/usr/share/pixmaps/blanker-screen.png";
   char *tmp_path = NULL, *tmp_path2 = NULL;
@@ -449,6 +460,24 @@ build_menu(void)
   if (tmp_path) free(tmp_path);
   if (tmp_path2) free(tmp_path2);
 
+  if (XmmsControl) {
+    mb_menu_add_item_to_menu(app_data->mbmenu, m,
+			     "XMMS Control",
+			     "/usr/share/pixmaps/blanker-yes.png",
+			     "",
+			     xmms_callback,
+			     NULL, MBMENU_NO_SORT);
+  } else {
+    mb_menu_add_item_to_menu(app_data->mbmenu, m,
+			     "XMMS Control",
+			     "/usr/share/pixmaps/blanker-no.png",
+			     "",
+			     xmms_callback,
+			     NULL, MBMENU_NO_SORT);
+  }
+
+  mb_menu_add_seperator_to_menu(app_data->mbmenu, m, MBMENU_NO_SORT);
+
   if (ScreensaverDisabled) {
     mb_menu_add_item_to_menu(app_data->mbmenu, m,
 			     "Enable Screensaver",
@@ -655,6 +684,10 @@ static gboolean key_event_callback( GtkWidget      *widget,
 				    GdkEventKey	   *event,
 				    gpointer        data )
 {
+  /* Return if xmms control is disabled */
+  if (!XmmsControl)
+    return FALSE;
+
   if (event->type == GDK_KEY_PRESS) {
     //printf("key pressed (%d)\n", event->keyval);
   } else if (event->type == GDK_KEY_RELEASE) {
@@ -838,11 +871,6 @@ main( int argc, char *argv[])
 				       &argv,
 				       GDK_DISPLAY ());
 
-  if (app == NULL) usage();
-  
-  if (argc > 1 && strstr(argv[1], "-h"))
-    usage();
-
   app_data->tray_app = app;
 
   app_data->mbtheme_atom 
@@ -885,6 +913,13 @@ main( int argc, char *argv[])
    act.sa_handler = reap_children;
    sigaction(SIGCHLD, &act, NULL);
 
+   /* Reset dpms and backlight to config values if backlight is currently off,
+      since we assume it was our fault */
+   if (get_backlight() == 0) {
+     set_dpms();
+     enable_backlight();
+   }
+
    /* Initialise popup window (starts off hidden) and key event handling */
    popup_init(app);
    g_signal_connect (G_OBJECT (blanker_window), "key-press-event",
@@ -892,13 +927,6 @@ main( int argc, char *argv[])
    g_signal_connect (G_OBJECT (blanker_window), "key-release-event",
 		     G_CALLBACK (key_event_callback), NULL);
 
-   /* Reset dpms and backlight to config values (just because we can) */
-   set_dpms();
-   enable_backlight();
-
-   /* Disable X screensaver (kludge) */
-   fork_exec("/usr/X11R6/bin/xset s 0");
-
    mb_tray_app_set_icon(app, app_data->pb, app_data->img_tray);
 
    mb_tray_app_main_init (app);
